<?php

namespace Drupal\semantic_search\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\Node;
use Algenza\Cosinesimilarity\Cosine;

/**
 * SemanticSearchForm form class.
 */
class SemanticSearchForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'semantic_search_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['semantic_search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    if ($form_state->getValue('semantic_search')) {
      $similarity_min = \Drupal::config('semantic_search.settings')->get('similarity_min');

      $embedding_service = \Drupal::service('semantic_search.openai_embedding');
      $search_embedding = $embedding_service->getEmbedding($form_state->getValue('semantic_search'));
      $embeddings = $embedding_service->getSavedEmbeddings();

      foreach ($embeddings as $key => $embedding) {
        $cosine_similarity = Cosine::similarity($search_embedding, $embedding);
        if ($cosine_similarity > floatval($similarity_min)) {
          $similarities[$key] = $cosine_similarity;
        }
      }

      if ($similarities) {

        arsort($similarities);

        foreach ($similarities as $key => $similarity) {
          $search_ids[$key] = $key;
        }

        $nodes = Node::loadMultiple($search_ids);

        foreach ($nodes as $node) {
          // @todo display teaser.
          $form['semantic_search_result'][] = ['#markup' => '<div><a href="' . $node->toUrl()->toString() . '">' . $node->getTitle() . '</a></div>'];
        }
      }
      else {
        $form['semantic_search_result'][] = ['#markup' => '<div>' . $this->t('No match found') . '</div>'];
      }

    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $form_state->setRebuild(TRUE);

  }

}
