<?php

namespace Drupal\semantic_search\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Semantic Search configuration form.
 */
class SemanticSearchSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'semantic_search.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'semantic_search_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('semantic_search.settings');

    $form['openai_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OpenAI Key'),
      '#description' => $this->t('OpenAI Key.'),
      '#default_value' => $config->get('openai_key'),
      '#required' => TRUE,
    ];

    $similarity_options = [];
    foreach (range(99, 70, 1) as $number) {
      $similarity_options['0.' . $number] = '0.' . $number;
    }

    $form['similarity_min'] = [
      '#type' => 'select',
      '#options' => $similarity_options,
      '#title' => $this->t('Similarity Minimum'),
      '#description' => $this->t('Similarity Minimum'),
      '#default_value' => $config->get('similarity_min'),
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('semantic_search.settings')
      ->set('openai_key', trim($form_state->getValue('openai_key')))
      ->set('similarity_min', trim($form_state->getValue('similarity_min')))
      ->save();

  }

}
