<?php

namespace Drupal\semantic_search\Services;

use Drupal\Core\File\FileSystemInterface;

/**
 * Get embeddings from OpenAI.
 *
 * @package Drupal\semantic_search\Services
 */
class OpenAiEmbeddingService {

  /**
   * The embeddings private directory.
   *
   * @var string
   */
  protected $embeddingPrivateDir = 'private://semantic_search/';

  /**
   * The embeddings private directory.
   *
   * @var string
   */
  protected $embeddingPrivateFile = 'semantic_search_vectors.json';
  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs for OpenAiEmbeddingService.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(FileSystemInterface $file_system) {
    $this->fileSystem = $file_system;
  }

  /**
   * Get embedding from Openai.
   *
   * @return array
   *   OpenAI embedding.
   */
  public function getEmbedding($source) {

    $openai_key = \Drupal::config('semantic_search.settings')->get('openai_key');
    $client = \OpenAI::client($openai_key);
    $response = $client->embeddings()->create([
      'model' => 'text-embedding-ada-002',
      'input' => strip_tags($source),
    ]);

    foreach ($response->embeddings as $embedding) {
      $embedding = $embedding->embedding;
    }

    return $embedding;
  }

  /**
   * Save embeddings to file.
   */
  public function saveEmbeddings($embeddings) {

    $path = $this->embeddingPrivateDir;
    $this->fileSystem->prepareDirectory($path, FileSystemInterface::CREATE_DIRECTORY);

    $response_file = $this->embeddingPrivateFile;
    $this->fileSystem->saveData(json_encode($embeddings, TRUE), $path . '/' . $response_file, TRUE);

  }

  /**
   * Get saved embeddings from file.
   *
   * @return array
   *   Saved embeddings.
   */
  public function getSavedEmbeddings() {

    $saved_embeddings = [];
    $filepath = $this->embeddingPrivateDir . $this->embeddingPrivateFile;
    if (file_exists($filepath)) {
      $embedding_data = file_get_contents($filepath);
      $saved_embeddings = json_decode($embedding_data, TRUE);
    }
    return $saved_embeddings;
  }

}
